@@ -91,6 +91,14 @@
 # error You must define a card identifier...
 #endif
 
+/* deprecated IRQF_DISABLED is a NOOP for a long time.
+ * The flag was removed entirely with kernel 4.1.
+ */
+#ifndef IRQF_DISABLED
+# define IRQF_DISABLED 0x0
+#endif
+
+
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
 card_t *			capi_card		= NULL;
@@ -124,7 +132,7 @@ static DECLARE_TASKLET_DISABLED (scheduler_tasklet, scheduler, 0);
 static __attr void scheduler_control (unsigned);
 
 static functions_t	cafuncs = {
-	
+
 	1,	/* 7 */
 	scheduler_control,
 #if 0
